==> gesundheit-0.1.2.tgz: package/lib/select.js <==
(function() {
  var SUDQuery, Select, fluid, makeFrom, normalize, _ref;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  }, __slice = Array.prototype.slice;
  fluid = require('./fluid');
  normalize = require('./normalize');
  _ref = require('./sud-query'), SUDQuery = _ref.SUDQuery, makeFrom = _ref.makeFrom;
  module.exports = Select = (function() {
    __extends(Select, SUDQuery);
    function Select(table, opts) {
      var alias, _ref2;
      if (opts == null) {
        opts = {};
      }
      Select.__super__.constructor.call(this, table, opts);
      this.s.queryType = 'Select';
      this.s.fields = {};
      this.s.groupings = [];
      if (table != null) {
        _ref2 = this.aliasPair(table), table = _ref2[0], alias = _ref2[1];
        this.s.fields[alias] = [];
      }
    }
    Select.prototype.fields = fluid(function() {
      var al, alias, aliased, f, fa, fieldAlias, fieldName, fields, fn, table, _base, _i, _len, _ref2, _ref3, _ref4, _results;
      fields = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
      alias = !(fields[1] && fields[1].constructor === Array) ? this.lastAlias() : ((_ref2 = this.aliasPair(fields.shift()), table = _ref2[0], al = _ref2[1], _ref2), !this.includesAlias(al) ? unknown('table', table) : void 0);
      if (fields.length === 0) {
        return this.s.fields[alias] = null;
      }
      _results = [];
      for (_i = 0, _len = fields.length; _i < _len; _i++) {
        f = fields[_i];
        aliased = typeof f === 'object' && Object.keys(f).length === 1;
        _ref3 = !aliased ? [f, f] : ((function() {
          var _results2;
          _results2 = [];
          for (fa in f) {
            fn = f[fa];
            _results2.push([fn, fa]);
          }
          return _results2;
        })())[0], fieldName = _ref3[0], fieldAlias = _ref3[1];
        fieldName = this.resolve.field(alias, fieldName);
        if (!aliased) {
          fieldAlias = fieldName;
        }
        if ((_ref4 = (_base = this.s.fields)[alias]) == null) {
          _base[alias] = [];
        }
        _results.push(this.s.fields[alias].push([fieldName, fieldAlias]));
      }
      return _results;
    });
    Select.prototype.field = function() {
      var f;
      f = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
      return this.fields.apply(this, f);
    };
    Select.prototype.groupBy = function() {
      var alias, field, fields, groupings, _ref2;
      fields = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
      alias = this.lastAlias();
      groupings = (function() {
        var _i, _len, _results;
        _results = [];
        for (_i = 0, _len = fields.length; _i < _len; _i++) {
          field = fields[_i];
          _results.push({
            table: alias,
            field: field
          });
        }
        return _results;
      })();
      return (_ref2 = this.s.groupings).push.apply(_ref2, groupings);
    };
    return Select;
  })();
  Select.from = function(tbl, fields, opts) {
    var query;
    if (tbl instanceof Select) {
      throw new Error("Inner queries not supported yet");
    }
    if ((fields != null) && fields.constructor !== Array) {
      opts = fields;
      fields = null;
    }
    query = new Select(tbl, opts);
    if (fields != null) {
      query.fields.apply(query, fields);
    }
    return query;
  };
}).call(this);

==> gesundheit-0.1.3.tgz: package/lib/select.js <==
(function() {
  var SUDQuery, Select, fluid, makeFrom, normalize, _ref;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  }, __slice = Array.prototype.slice;
  fluid = require('./fluid');
  normalize = require('./normalize');
  _ref = require('./sud-query'), SUDQuery = _ref.SUDQuery, makeFrom = _ref.makeFrom;
  module.exports = Select = (function() {
    __extends(Select, SUDQuery);
    function Select(table, opts) {
      var alias, _ref2;
      if (opts == null) {
        opts = {};
      }
      Select.__super__.constructor.call(this, table, opts);
      this.s.queryType = 'Select';
      this.s.fields = {};
      this.s.groupings = [];
      if (table != null) {
        _ref2 = this.aliasPair(table), table = _ref2[0], alias = _ref2[1];
        this.s.fields[alias] = [];
      }
    }
    Select.prototype.fields = fluid(function() {
      var alias, fields, oldfields;
      fields = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
      alias = fields[1] && Array.isArray(fields[1]) ? (oldfields = fields, fields = fields[1], !this.includesAlias(oldfields[0]) ? unknown('table', table) : void 0, oldfields[0]) : this.lastAlias();
      if (fields.length === 0) {
        return this.s.fields[alias] = null;
      }
      return this._fields(alias, fields);
    });
    Select.prototype.agg = fluid(function() {
      var alias, fields, fun;
      fun = arguments[0], fields = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
      alias = this.lastAlias();
      return fields = this._fields(alias, fields, fun);
    });
    Select.prototype._fields = function(alias, fields, agg) {
      var aliased, f, fa, fieldAlias, fieldName, fn, _base, _i, _len, _ref2, _ref3, _results;
      if ((_ref2 = (_base = this.s.fields)[alias]) == null) {
        _base[alias] = [];
      }
      _results = [];
      for (_i = 0, _len = fields.length; _i < _len; _i++) {
        f = fields[_i];
        aliased = typeof f === 'object' && Object.keys(f).length === 1;
        _ref3 = aliased ? ((function() {
          var _results2;
          _results2 = [];
          for (fa in f) {
            fn = f[fa];
            _results2.push([fn, fa]);
          }
          return _results2;
        })())[0] : [f, f], fieldName = _ref3[0], fieldAlias = _ref3[1];
        fieldName = this.resolve.field(alias, fieldName);
        if (!aliased) {
          fieldAlias = fieldName;
        }
        _results.push(this.s.fields[alias].push([fieldName, fieldAlias, agg]));
      }
      return _results;
    };
    Select.prototype.groupBy = function() {
      var alias, field, fields, groupings, _ref2;
      fields = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
      alias = this.lastAlias();
      groupings = (function() {
        var _i, _len, _results;
        _results = [];
        for (_i = 0, _len = fields.length; _i < _len; _i++) {
          field = fields[_i];
          _results.push({
            table: alias,
            field: field
          });
        }
        return _results;
      })();
      return (_ref2 = this.s.groupings).push.apply(_ref2, groupings);
    };
    return Select;
  })();
  Select.prototype.field = Select.prototype.fields;
  Select.from = function(tbl, fields, opts) {
    var query;
    if (tbl instanceof Select) {
      throw new Error("Inner queries not supported yet");
    }
    if ((fields != null) && fields.constructor !== Array) {
      opts = fields;
      fields = null;
    }
    query = new Select(tbl, opts);
    if (fields != null) {
      query.fields.apply(query, fields);
    }
    return query;
  };
}).call(this);
